@@ -4,7 +4,6 @@ import (
 	"io"
 	"os"
 	"os/exec"
-	"path/filepath"
 	"runtime"
 	"sync"
 	"sync/atomic"
@@ -420,7 +419,7 @@ func TestLockfileWriteConcurrent(t *testing.T) {
 	var wg sync.WaitGroup
 	var highestMutex sync.Mutex
 	var counter, highest int64
-	for i := 0; i < 8000; i++ {
+	for range 8000 {
 		wg.Add(1)
 		go func() {
 			l.Lock()
@@ -456,7 +455,7 @@ func TestLockfileReadConcurrent(t *testing.T) {
 	unlocked := make(chan bool)
 	done := make(chan bool)
 
-	for i := 0; i < numReaders; i++ {
+	for range numReaders {
 		go func() {
 			l.RLock()
 			locked <- true
@@ -467,15 +466,15 @@ func TestLockfileReadConcurrent(t *testing.T) {
 	}
 
 	// Wait for all parallel locks to succeed
-	for i := 0; i < numReaders; i++ {
+	for range numReaders {
 		<-locked
 	}
 	// Instruct all parallel locks to unlock
-	for i := 0; i < numReaders; i++ {
+	for range numReaders {
 		unlocked <- true
 	}
 	// Wait for all parallel locks to be unlocked
-	for i := 0; i < numReaders; i++ {
+	for range numReaders {
 		<-done
 	}
 }
@@ -496,7 +495,7 @@ func TestLockfileMixedConcurrent(t *testing.T) {
 	// A writer always adds `diff` to the counter. Hence, `diff` is the
 	// only valid value in the critical section.
 	writer := func(c *int32) {
-		for i := 0; i < numIterations; i++ {
+		for range numIterations {
 			l.Lock()
 			tmp := atomic.AddInt32(c, diff)
 			assert.True(t, tmp == diff, "counter should be %d but instead is %d", diff, tmp)
@@ -510,7 +509,7 @@ func TestLockfileMixedConcurrent(t *testing.T) {
 	// A reader always adds `1` to the counter. Hence,
 	// [1,`numReaders*numIterations`] are valid values.
 	reader := func(c *int32) {
-		for i := 0; i < numIterations; i++ {
+		for range numIterations {
 			l.RLock()
 			tmp := atomic.AddInt32(c, 1)
 			assert.True(t, tmp >= 1 && tmp < diff)
@@ -521,7 +520,7 @@ func TestLockfileMixedConcurrent(t *testing.T) {
 		done <- true
 	}
 
-	for i := 0; i < numReaders; i++ {
+	for i := range numReaders {
 		go reader(&counter)
 		// schedule a writer every 2nd iteration
 		if i%2 == 1 {
@@ -529,7 +528,7 @@ func TestLockfileMixedConcurrent(t *testing.T) {
 		}
 	}
 
-	for i := 0; i < numReaders+numWriters; i++ {
+	for range numReaders + numWriters {
 		<-done
 	}
 }
@@ -844,59 +843,3 @@ func TestLockfileMultiprocessModifiedSince(t *testing.T) {
 	require.NoError(t, err)
 	assert.False(t, modified)
 }
-
-func TestOpenLock(t *testing.T) {
-	t.Parallel()
-
-	for _, tc := range []struct {
-		name    string
-		prepare func() (path string, readOnly bool)
-	}{
-		{
-			name: "file exists (read/write)",
-			prepare: func() (string, bool) {
-				tempFile, err := os.CreateTemp("", "lock-")
-				require.NoError(t, err)
-				tempFile.Close()
-				return tempFile.Name(), false
-			},
-		},
-		{
-			name: "file exists readonly (readonly)",
-			prepare: func() (string, bool) {
-				tempFile, err := os.CreateTemp("", "lock-")
-				require.NoError(t, err)
-				tempFile.Close()
-				return tempFile.Name(), true
-			},
-		},
-		{
-			name: "base dir exists (read/write)",
-			prepare: func() (string, bool) {
-				tempDir := os.TempDir()
-				require.DirExists(t, tempDir)
-				return filepath.Join(tempDir, "test-1.lock"), false
-			},
-		},
-		{
-			name: "base dir not exists (read/write)",
-			prepare: func() (string, bool) {
-				tempDir, err := os.MkdirTemp("", "lock-")
-				require.NoError(t, err)
-				return filepath.Join(tempDir, "subdir", "test-1.lock"), false
-			},
-		},
-	} {
-		path, readOnly := tc.prepare()
-
-		fd, err := openLock(path, readOnly)
-		require.NoError(t, err, tc.name)
-		unlockAndCloseHandle(fd)
-
-		fd, err = openLock(path, readOnly)
-		require.NoError(t, err)
-		unlockAndCloseHandle(fd)
-
-		require.Nil(t, os.RemoveAll(path))
-	}
-}
